==> jc-1.4.0.tar.gz: java/io/StringBufferInputStream.h <==
// public class java.io.StringBufferInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class ce23511edac95fd4 java_io_StringBufferInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_io_StringBufferInputStream_H_
#define _JC_java_io_StringBufferInputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_StringBufferInputStream$sub_refs	_jc_java_io_StringBufferInputStream$sub_refs;
typedef struct _jc_java_io_StringBufferInputStream$sub_nonrefs	_jc_java_io_StringBufferInputStream$sub_nonrefs;
typedef struct _jc_java_io_StringBufferInputStream$refs	_jc_java_io_StringBufferInputStream$refs;
typedef struct _jc_java_io_StringBufferInputStream$nonrefs	_jc_java_io_StringBufferInputStream$nonrefs;
typedef struct _jc_java_io_StringBufferInputStream$object	_jc_java_io_StringBufferInputStream$object;

typedef const struct _jc_java_io_StringBufferInputStream$vmethods	_jc_java_io_StringBufferInputStream$vmethods;
typedef const struct _jc_java_io_StringBufferInputStream$vtable	_jc_java_io_StringBufferInputStream$vtable;
typedef const struct _jc_java_io_StringBufferInputStream$vtype	_jc_java_io_StringBufferInputStream$vtype;

// Constructors
extern void _jc_java_io_StringBufferInputStream$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_java_io_StringBufferInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
extern jint _jc_java_io_StringBufferInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
extern jint _jc_java_io_StringBufferInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_io_StringBufferInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
extern jlong _jc_java_io_StringBufferInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, jlong);
extern void _jc_java_io_StringBufferInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$skip$4e431136b5c4614a;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_io_StringBufferInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, jlong);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *);
};

// Vtable
struct _jc_java_io_StringBufferInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_StringBufferInputStream$vmethods	java_io_StringBufferInputStream;
};

// Vtype
struct _jc_java_io_StringBufferInputStream$vtype {
	_jc_type			type;
	_jc_java_io_StringBufferInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_StringBufferInputStream$sub_refs {
	struct _jc_java_lang_String$object	*buffer;
};

// Reference instance fields (object)
struct _jc_java_io_StringBufferInputStream$refs {
    _jc_java_io_StringBufferInputStream$sub_refs	java_io_StringBufferInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_StringBufferInputStream$sub_nonrefs {
	jint	pos;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_StringBufferInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_StringBufferInputStream$sub_nonrefs	java_io_StringBufferInputStream;
};

// Object instance structure
struct _jc_java_io_StringBufferInputStream$object {
	_jc_java_io_StringBufferInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_StringBufferInputStream$vtype	*vtype;
	_jc_java_io_StringBufferInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_StringBufferInputStream$vtype _jc_java_io_StringBufferInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_StringBufferInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_StringBufferInputStream$class_object;

#endif	/* _JC_java_io_StringBufferInputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/StringBufferInputStream.h <==
// public class java.io.StringBufferInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class ce23511edac95fd4 java_io_StringBufferInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_io_StringBufferInputStream_H_
#define _JC_java_io_StringBufferInputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_StringBufferInputStream$sub_refs	_jc_java_io_StringBufferInputStream$sub_refs;
typedef struct _jc_java_io_StringBufferInputStream$sub_nonrefs	_jc_java_io_StringBufferInputStream$sub_nonrefs;
typedef struct _jc_java_io_StringBufferInputStream$refs	_jc_java_io_StringBufferInputStream$refs;
typedef struct _jc_java_io_StringBufferInputStream$nonrefs	_jc_java_io_StringBufferInputStream$nonrefs;
typedef struct _jc_java_io_StringBufferInputStream$object	_jc_java_io_StringBufferInputStream$object;

typedef const struct _jc_java_io_StringBufferInputStream$vmethods	_jc_java_io_StringBufferInputStream$vmethods;
typedef const struct _jc_java_io_StringBufferInputStream$vtable	_jc_java_io_StringBufferInputStream$vtable;
typedef const struct _jc_java_io_StringBufferInputStream$vtype	_jc_java_io_StringBufferInputStream$vtype;

// Constructors
extern void _jc_java_io_StringBufferInputStream$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_StringBufferInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_StringBufferInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_StringBufferInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_StringBufferInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_io_StringBufferInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_java_io_StringBufferInputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$skip$4e431136b5c4614a;
extern _jc_method _jc_java_io_StringBufferInputStream$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_io_StringBufferInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *, jlong) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_io_StringBufferInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_StringBufferInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_StringBufferInputStream$vmethods	java_io_StringBufferInputStream;
};

// Vtype
struct _jc_java_io_StringBufferInputStream$vtype {
	_jc_type			type;
	_jc_java_io_StringBufferInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_StringBufferInputStream$sub_refs {
	struct _jc_java_lang_String$object	*buffer;
};

// Reference instance fields (object)
struct _jc_java_io_StringBufferInputStream$refs {
    _jc_java_io_StringBufferInputStream$sub_refs	java_io_StringBufferInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_StringBufferInputStream$sub_nonrefs {
	jint	pos;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_StringBufferInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_StringBufferInputStream$sub_nonrefs	java_io_StringBufferInputStream;
};

// Object instance structure
struct _jc_java_io_StringBufferInputStream$object {
	_jc_java_io_StringBufferInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_StringBufferInputStream$vtype	*vtype;
	_jc_java_io_StringBufferInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_StringBufferInputStream$vtype _jc_java_io_StringBufferInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_StringBufferInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_StringBufferInputStream$class_object;

#endif	/* _JC_java_io_StringBufferInputStream_H_ */
